// Copyright 2023 Michael Amann and contributors
// SPDX-License-Identifier: AGPL-3.0-only

package file

import "git.kle.li/tools/go-import-redirector/pkg/constants"

type CfgFile struct {
	Host     string
	Defaults *Defaults
	Modules  []*Module
}

type Defaults struct {
	SourceType string
	VcsType    string
	Branch     string
}

type Module struct {
	Path       string
	Repo       string
	VcsType    string
	SourceType string
	// Branch is used to build the file and directory URLs for the automated modes
	Branch string
	// see https://github.com/golang/gddo/wiki/Source-Code-Links for home, direcory and file
	HomeURL      string
	DirectoryURL string
	FileURL      string
	Title        string
}

func (d *Defaults) applyGlobalDefaults() {
	if d.Branch == "" {
		d.Branch = constants.DefaultBranch
	}

	if d.SourceType == "" {
		d.SourceType = constants.DefaultSourceType
	}

	if d.VcsType == "" {
		d.VcsType = constants.DefaultVcs
	}
}

func (m *Module) applyDefaults(d *Defaults) {
	if m.Branch == "" {
		m.Branch = d.Branch
	}

	if m.VcsType == "" {
		m.VcsType = d.VcsType
	}

	if m.SourceType == "" {
		m.SourceType = d.SourceType
	}
}

func (c *CfgFile) UpdateCfgWithDefaults() {
	if c.Defaults == nil {
		c.Defaults = &Defaults{}
	}

	c.Defaults.applyGlobalDefaults()

	for _, m := range c.Modules {
		m.applyDefaults(c.Defaults)
	}
}
