// Copyright 2023 Michael Amann and contributors
// SPDX-License-Identifier: AGPL-3.0-only

package packagelist

import "html/template"

var (
	indexTmpl = template.Must(template.New("index").Parse(indexView))
	pkgTmpl   = template.Must(template.New("pkg").Parse(pkgView))
)

const indexView = `
<html>
	<head>
		{{if .pkg}}
			<meta name="go-import" content="{{.pkg.Import}}">
			{{if .pkg.Source}}
			<meta name="go-source" content="{{.pkg.Source}}">
			{{end}}
		{{end}}
		<title>Go Import Redirector - Packages</title>
	</head>
	<body>
		{{if .pkg}}
			<h1>{{.pkg.Title}}</h1>
			<span style="font-weight: bold">Repo-Root:</span> {{.pkg.Repo}}<br>
			{{if .pkg.Home}}
			<span style="font-weight: bold">Home / Docs:</span> <a href="{{.pkg.Home}}">{{.pkg.Home}}</a><br>
			{{end}}
			<h2>Other Packages</h2>
		{{else}}
			<h1>Packages</h1>
		{{end}}
		<ul>
			{{$host := .host}}
			{{range .pkgs}}
				<li><a href="{{.Path}}">{{$host}}{{.Path}}</a></li>
			{{end}}
		</ul>
	</body>
</html>
`

const pkgView = `
<html>
	<head>
		<meta name="go-import" content="{{.pkg.Import}}">
        {{if .pkg.Source}}
        <meta name="go-source" content="{{.pkg.Source}}">
        {{end}}
		<title>{{.pkg.Title}}</title>
	</head>
	<body>
		<h1>{{.pkg.Title}}</h1>
		<span style="font-weight: bold">Repo-Root:</span> {{.pkg.Repo}}<br>
        {{if .pkg.Home}}
        <span style="font-weight: bold">Home / Docs:</span> <a href="{{.pkg.Home}}">{{.pkg.Home}}</a><br>
        {{end}}
	</body>
</html>
`
